/*
 * Copyright 1999-2007 Christos KK Loverdos.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ckkloverdos.log;

import org.ckkloverdos.string.ToString;

/**
 * Just a convenience utility class to replace <code>System.out.println</code> calls.
 *
 * This a very limited logging API.
 * It is better to use {@link org.ckkloverdos.log.StdLogger} instead.
 *
 * @author Christos KK Loverdos
 */
public final class StdLog
{
    private static final StdLogger log = new StdLogger(null, null, true, 1);
    private StdLog(){}

    public static void log(String msg)
    {
        log.log(msg);
    }

    public static void log(boolean b)
    {
        log.log(b);
    }

    public static void log(String key, Object val)
    {
        log.log(key, val);
    }

    public static void log(String msg, String key, Object val)
    {
        log.log(msg, key, val);
    }

    public static void log(String key, Object val, String k2, Object v2)
    {
        log.log(key, val, k2, v2);
    }

    public static void log(String msg, String key, Object val, String k2, Object v2)
    {
        log.log(msg, key, val, k2, v2);
    }

    public static void log(String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.log(key, val, k2, v2, k3, v3);
    }

    public static void log(String msg, String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.log(msg, key, val, k2, v2, k3, v3);
    }

    public static void log(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.log(key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void log(String msg, String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.log(msg, key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void log(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5)
    {
        log.log(key, val, k2, v2, k3, v3, k4, v4, k5, v5);
    }

    public static void log(String msg, String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5)
    {
        log.log(msg, key, val, k2, v2, k3, v3, k4, v4, k5, v5);
    }

    public static void log(ToString msg)
    {
        log.log(msg);
    }

    public static void log(Throwable msg)
    {
        log.log(msg);
    }

    public static void log(Object msg)
    {
        log.log(msg);
    }

    public static void debug(String msg)
    {
        log.debug(msg);
    }

    public static void debug(ToString msg)
    {
        log.debug(msg);
    }

    public static void debug(Throwable e)
    {
        log.debug(e);
    }

    public static void debug(String msg, Throwable e)
    {
        log.debug(msg, e);
    }

    public static void debug(ToString msg, Throwable e)
    {
        log.debug(msg, e);
    }

    public static void debug(Object o, Throwable e)
    {
        log.debug(o, e);
    }

    public static void debug(Object msg)
    {
        log.debug(msg);
    }

    public static void debug(String key, Object val)
    {
        log.debug(key, val);
    }

    public static void debug(String msg, String key, Object val)
    {
        log.debug(msg, key, val);
    }

    public static void debug(String key, Object val, String k2, Object v2)
    {
        log.debug(key, val, k2, v2);
    }

    public static void debug(String msg, String key, Object val, String k2, Object v2)
    {
        log.debug(msg, key, val, k2, v2);
    }

    public static void debug(String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.debug(key, val, k2, v2, k3, v3);
    }

    public static void debug(String msg, String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.debug(msg, key, val, k2, v2, k3, v3);
    }

    public static void debug(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.debug(key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void debug(String msg, String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.debug(msg, key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void debug(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5)
    {
        log.debug(key, val, k2, v2, k3, v3, k4, v4, k5, v5);
    }

    public static void info(ToString msg)
    {
        log.info(msg);
    }

    public static void info(Throwable e)
    {
        log.info(e);
    }

    public static void info(String msg, Throwable e)
    {
        log.info(msg, e);
    }

    public static void info(ToString msg, Throwable e)
    {
        log.info(msg, e);
    }

    public static void info(Object o, Throwable e)
    {
        log.info(o, e);
    }

    public static void info(Object msg)
    {
        log.info(msg);
    }

    public static void info(String key, Object val)
    {
        log.info(key, val);
    }

    public static void info(String msg, String key, Object val)
    {
        log.info(msg, key, val);
    }

    public static void info(String key, Object val, String k2, Object v2)
    {
        log.info(key, val, k2, v2);
    }

    public static void info(String msg, String key, Object val, String k2, Object v2)
    {
        log.info(msg, key, val, k2, v2);
    }

    public static void info(String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.info(key, val, k2, v2, k3, v3);
    }

    public static void info(String msg, String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.info(msg, key, val, k2, v2, k3, v3);
    }

    public static void info(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.info(key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void info(String msg, String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.info(msg, key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void info(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5)
    {
        log.info(key, val, k2, v2, k3, v3, k4, v4, k5, v5);
    }

    public static void warn(String msg)
    {
        log.warn(msg);
    }

    public static void warn(ToString msg)
    {
        log.warn(msg);
    }

    public static void warn(Throwable e)
    {
        log.warn(e);
    }

    public static void warn(String msg, Throwable e)
    {
        log.warn(msg, e);
    }

    public static void warn(ToString msg, Throwable e)
    {
        log.warn(msg, e);
    }

    public static void warn(Object o, Throwable e)
    {
        log.warn(o, e);
    }

    public static void warn(Object msg)
    {
        log.warn(msg);
    }

    public static void warn(String key, Object val)
    {
        log.warn(key, val);
    }

    public static void warn(String msg, String key, Object val)
    {
        log.warn(msg, key, val);
    }

    public static void warn(String key, Object val, String k2, Object v2)
    {
        log.warn(key, val, k2, v2);
    }

    public static void warn(String msg, String key, Object val, String k2, Object v2)
    {
        log.warn(msg, key, val, k2, v2);
    }

    public static void warn(String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.warn(key, val, k2, v2, k3, v3);
    }

    public static void warn(String msg, String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.warn(msg, key, val, k2, v2, k3, v3);
    }

    public static void warn(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.warn(key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void warn(String msg, String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.warn(msg, key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void warn(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5)
    {
        log.warn(key, val, k2, v2, k3, v3, k4, v4, k5, v5);
    }

    public static void error(String msg)
    {
        log.error(msg);
    }

    public static void error(ToString msg)
    {
        log.error(msg);
    }

    public static void error(Throwable e)
    {
        log.error(e);
    }

    public static void error(String msg, Throwable e)
    {
        log.error(msg, e);
    }

    public static void error(ToString msg, Throwable e)
    {
        log.error(msg, e);
    }

    public static void error(Object o, Throwable e)
    {
        log.error(o, e);
    }

    public static void error(Object msg)
    {
        log.error(msg);
    }

    public static void error(String key, Object val)
    {
        log.error(key, val);
    }

    public static void error(String msg, String key, Object val)
    {
        log.error(msg, key, val);
    }

    public static void error(String key, Object val, String k2, Object v2)
    {
        log.error(key, val, k2, v2);
    }

    public static void error(String msg, String key, Object val, String k2, Object v2)
    {
        log.error(msg, key, val, k2, v2);
    }

    public static void error(String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.error(key, val, k2, v2, k3, v3);
    }

    public static void error(String msg, String key, Object val, String k2, Object v2, String k3, Object v3)
    {
        log.error(msg, key, val, k2, v2, k3, v3);
    }

    public static void error(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.error(key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void error(String msg, String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4)
    {
        log.error(msg, key, val, k2, v2, k3, v3, k4, v4);
    }

    public static void error(String key, Object val, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5)
    {
        log.error(key, val, k2, v2, k3, v3, k4, v4, k5, v5);
    }

    public static void setUID(String uid)
    {
        log.setUID(uid);
    }

    public static void setWhere(String where)
    {
        log.setWhere(where);
    }

    public static String getWhere()
    {
        return log.getWhere();
    }

    public static String getUID()
    {
        return log.getUID();
    }

    public static void enter()
    {
        log.enter();
    }

    public static void exit()
    {
        log.exit();
    }

    public static void main(String[] args)
    {
        StdLog.log("Hello world!");
        StdLogger log = new StdLogger();
        log.log("Hello world!");
        log.indent();
        log.log("One");
        log.log("Two");
        log.log("Three");
        log.unindent();
        log = log.forSite("another");
        log.log("Hello world!");
        log.indent();
        log.log("One");
        log.log("Two");
        log.log("Three");
        log.unindent();
    }
}
